# deleter
 Delete Python script at exit.

## Installation

From PyPI

```shell
pip install deleter -U
```

From sources

```shell
git clone https://github.com/desty2k/deleter.git
cd deleter
pip install .
```

## Usage

```python
import deleter

deleter.register()

# your code
```
